
quoter
======

``quoter`` provides a simple, powerful, systematic way do accomplish
one of the most common low-level operations in Python programming:
combing strings and data objects into other strings. It does so with
remarkable intelligence, including for complex textual langauges
such as HTML and XML.

.. toctree::
   :titlesonly:

   intro
   Cloning and Setting <setting>
   Formatting and Encoding <encoding>
   Shortcuts <shortcuts>
   Style Sets <stylesets>
   HTML <html>
   XML <xml>
   Named Styles <named>
   Dynamic Quoters <dynamic>
   Markdown <markdown>
   Joiners <joiners>
   API Reference <api>
   Notes <notes>
   install
   CHANGES
